@@ -412,16 +412,20 @@ def stitching():
 
 @stitching.command(name='setup')
 @click.argument("argument", type=click.STRING)
-@click.option('-o', "--output", type=click.Path(exists=True, dir_okay=True, file_okay=False), default=".")
+@click.option('-o', "--output", type=click.Path(dir_okay=True, file_okay=False))
 @click.option('-c', '--concurrency', default=8, type=click.INT)
 @pass_rebotics_context
 def stitching_setup(ctx, argument, concurrency, output):
     """
     argument - id of stitching debug data from admin, or json file
     """
-    output = pathlib.Path(output).absolute()
+    if output:
+        output = pathlib.Path(output).absolute()
+    else:
+        output = pathlib.Path('.').absolute()
+    output = output / f"stitching_{argument.replace(' ', '_')}"
     output.mkdir(parents=True, exist_ok=True)
-
+    ctx.verbose_log(f"Target directory is: {output}")
     filepath = output / "definition.json"
 
     if argument.isdigit():
@@ -449,7 +453,7 @@ def stitching_setup(ctx, argument, concurrency, output):
         definition = definition['data']
 
     if ctx.verbose:
-        ctx.format_result(definition['context'])
+        ctx.format_result(definition['context'], force_format='json')
 
     files_to_load = []  # pair of remote_url to local path
 
@@ -477,11 +481,12 @@ def stitching_setup(ctx, argument, concurrency, output):
         except:
             ctx.verbose_log("No stitching image is available")
 
-        mask_od_path = call_folder / "mask_od.json"
-        stitching_input['mask_od'] = str(mask_od_path)
-        files_to_load.append([
-            input_data['mask_od_url'], mask_od_path
-        ])
+        if input_data.get('mask_od_url'):
+            mask_od_path = call_folder / "mask_od.json"
+            stitching_input['mask_od'] = str(mask_od_path)
+            files_to_load.append([
+                input_data['mask_od_url'], mask_od_path
+            ])
 
         # register input files
         frames_folder = call_folder / "frames"
@@ -497,7 +502,7 @@ def stitching_setup(ctx, argument, concurrency, output):
         frames_folder = call_folder / "annotated_frames"
         frames_folder.mkdir(parents=True, exist_ok=True)
 
-        for frame_url in input_data['annotated_frames']:
+        for frame_url in input_data.get('annotated_frames', []):
             frame_path = frames_folder / get_filename_from_url(frame_url)
             files_to_load.append([
                 frame_url, frame_path
@@ -507,7 +512,7 @@ def stitching_setup(ctx, argument, concurrency, output):
         with open(str(call_folder / "stitching_input.json"), 'w') as fp:
             json.dump(stitching_input, fp)
 
-    ctx.verbose_log(f"Registered files to downloading: {files_to_load}")
+    ctx.verbose_log(f"Registered files for downloading: {len(files_to_load)}")
 
     with Pool(concurrency) as pool:
         for _ in tqdm.tqdm(
