@@ -234,29 +234,32 @@ def option_default_from_configurations(conf_name):
 @click.option('-h', '--host', help='App host', prompt=True, cls=option_default_from_configurations('host'))
 @click.option('-u', '--user', prompt=True, cls=option_default_from_configurations('username'))
 @click.option('--password', prompt=True, hide_input=True, confirmation_prompt=False)
-@click.option('--verification_code', prompt=True)
 @pass_rebotics_context
-def configure(ctx, user, password, host, verification_code):
-    """Fetch token, save it and use the role of it.
-     Leave verification code empty"""
+def configure(ctx, user, password, host):
+    """Fetch token, save it and use the role of it."""
     provider = ctx.provider_class(host=host)
     ctx.update_configuration(
         host=host,
     )
     try:
-        response = provider.token_auth(user, password, verification_code)
+        response = provider.token_auth(user, password)
     except ProviderHTTPClientException as e:
-        click.echo('Failed to login')
-        click.echo(f'Exception: {e}')
-        return
+        raw_message = e.response.content.decode('utf-8')
+        if '2FA' in raw_message or 'code' in raw_message:
+            click.echo('Please enter the verification code from email.')
+            token = input('Verification code from email: ')
+            response = provider.token_auth(user, password, verification_code=token)
+        else:
+            click.echo("Failed to login because of %s" % str(e))
+            return
 
     ctx.update_configuration(
         host=host,
         date=datetime.now().strftime('%c'),
-        **response
+        **response.json()
     )
     click.echo('Saved configuration for {} in {}'.format(ctx.role, ctx.config_provider.filepath), err=True)
-    ctx.format_result(response)
+    ctx.format_result(response.json())
 
 
 @click.command()
