@@ -27,7 +27,7 @@ class FVMProvider(ReboticsBaseProvider):
         }
         return self.session.post(data=json)
 
-    @remote_service('/api/token-auth/')
+    @remote_service('/api/token-auth/', raw=True)
     def token_auth(self, username, password, verification_code=None):
         payload = dict(
             username=username,
@@ -36,9 +36,9 @@ class FVMProvider(ReboticsBaseProvider):
         if verification_code is not None:
             payload['verification_code'] = verification_code
 
-        json_data = self.session.post(data=payload)
-        self.headers['Authorization'] = 'Token %s' % json_data['token']
-        return json_data
+        response = self.session.post(data=payload)
+        self.headers['Authorization'] = 'Token %s' % response.json()['token']
+        return response
 
     @remote_service('/api/files/virtual/')
     def create_virtual_upload(self, filename, pk):
