@@ -48,7 +48,12 @@ def get_filename_from_url(url):
 
 
 def download_file(url, filepath=None, **params):
-    response = requests.get(url, stream=True, params=params)
+    response = requests.get(
+        url,
+        stream=True,
+        params=params,
+        timeout=remote_loaders.HTTP_TIMEOUTS,
+    )
     response.raise_for_status()
 
     if filepath is None:
